@@ -5,7 +5,10 @@ import logging
 import time
 
 import msal
+
 from azure.core.credentials import AccessToken
+from azure.identity import ClientSecretCredential as ClientSecretCredentialSync
+from azure.identity.aio import ClientSecretCredential as ClientSecretCredentialASync
 
 
 logger = logging.getLogger(__name__)
@@ -66,6 +69,9 @@ class ClientAuthorization:
         if None in [tenant_id, client_id, client_secret]:
             raise TypeError
 
+        self.tenant_id = tenant_id
+        self.client_id = client_id
+        self.client_secret = client_secret
         self.confidential_client_app = msal.ConfidentialClientApplication(
             authority=f'https://login.microsoftonline.com/{tenant_id}',
             client_id=client_id,
@@ -80,13 +86,13 @@ class ClientAuthorization:
         """
         Returns Azure credentials for sync methods.
         """
-        return AzureCredential(self.get_access_token())
+        return ClientSecretCredentialSync(self.tenant_id, self.client_id, self.client_secret)
 
     def get_credential_async(self) -> AzureCredentialAIO:
         """
         Returns Azure credentials for async methods.
         """
-        return AzureCredentialAIO(self.get_access_token())
+        return ClientSecretCredentialASync(self.tenant_id, self.client_id, self.client_secret)
 
     def get_access_token(self) -> str:
         """
