@@ -2,7 +2,6 @@
 Module for common pipeline classes and functions
 """
 from ..core.enums import TimeResolution
-from ..core.azure_client_authorization import ClientAuthorization
 from .azure_data_storage import DataSets
 
 
@@ -42,8 +41,5 @@ class OsirisPipeline:
         self.source_dataset_guid = source_dataset_guid
         self.time_resolution = time_resolution
 
-        self.client_auth = ClientAuthorization(tenant_id, client_id, client_secret)
-
-        self.datasets = DataSets(storage_account_url, filesystem_name,
-                                 source_dataset_guid, destination_dataset_guid,
-                                 self.client_auth.get_credential_sync(), time_resolution)
+        self.datasets = DataSets(tenant_id, client_id, client_secret, storage_account_url, filesystem_name,
+                                 source_dataset_guid, destination_dataset_guid, time_resolution)
